@@ -98,6 +98,7 @@ public:
     virtual QString text(int column) const;
     virtual void setText(int column, const QString &text);
 
+    bool isPlaying() const;
     void setPlaying(bool playing = true, bool master = true);
 
     void guessTagInfo(TagGuesser::Type type);
@@ -163,11 +164,6 @@ protected:
     PlaylistItem(CollectionListItem *item, Playlist *parent);
     PlaylistItem(CollectionListItem *item, Playlist *parent, QTreeWidgetItem *after);
 
-    /**
-     * This is the constructor that should be used by subclasses.
-     */
-    PlaylistItem(CollectionList *parent);
-
     /**
      * See the class documentation for an explanation of construction and deletion
      * of PlaylistItems.
@@ -200,6 +196,12 @@ protected:
 private:
     DataPtr d;
 
+    /**
+     * This is the constructor that should be used by CollectionList.
+     */
+    PlaylistItem(CollectionList *parent);
+    friend class CollectionList;
+
     void setup(CollectionListItem *item);
 
     CollectionListItem *m_collectionItem;
